@@ -1,6 +1,5 @@
 import pytest
 
-from auto_labeling_pipeline.label import ClassificationLabel, Seq2seqLabel, SequenceLabel
 from auto_labeling_pipeline.labels import ClassificationLabels, Seq2seqLabels, SequenceLabels
 
 
@@ -11,7 +10,6 @@ def example_classification_data():
         {'label': 'B'},
         {'label': 'C'}
     ]
-    labels = [ClassificationLabel(**label) for label in labels]
     labels = ClassificationLabels(labels)
     return labels
 
@@ -23,7 +21,6 @@ def example_sequence_data():
         {'label': 'B', 'start_offset': 1, 'end_offset': 2},
         {'label': 'C', 'start_offset': 2, 'end_offset': 3}
     ]
-    labels = [SequenceLabel(**label) for label in labels]
     labels = SequenceLabels(labels)
     return labels
 
@@ -35,11 +32,20 @@ def example_seq2seq_data():
         {'text': 'B'},
         {'text': 'C'}
     ]
-    labels = [Seq2seqLabel(**label) for label in labels]
     labels = Seq2seqLabels(labels)
     return labels
 
 
+@pytest.fixture
+def example_sequence_overlap_data():
+    labels = [
+        {'label': 'A', 'start_offset': 0, 'end_offset': 2},
+        {'label': 'B', 'start_offset': 1, 'end_offset': 2}
+    ]
+    labels = SequenceLabels(labels)
+    return labels
+
+
 class TestClassificationLabels:
 
     def test_filter_by_name(self, example_classification_data):
@@ -101,6 +107,10 @@ class TestSequenceLabels:
         labels = example_sequence_data.replace_label()
         assert labels == example_sequence_data
 
+    def test_remove_overlap(self, example_sequence_overlap_data):
+        labels = example_sequence_overlap_data.remove_overlapping()
+        assert len(labels.dict()) == 1
+
 
 class TestSeq2seqLabels:
 
